import{V as s,ac as p,f as b,R as c}from"./outputWidgets.be3472c2.js";import{B as y,b as u}from"./Text.c9febe27.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="1343eea8-2d21-42d1-bc24-1d606f01f0ab",e._sentryDebugIdIdentifier="sentry-dbid-1343eea8-2d21-42d1-bc24-1d606f01f0ab")}catch{}})();var g=globalThis&&globalThis.__rest||function(e,n){var o={};for(var t in e)Object.prototype.hasOwnProperty.call(e,t)&&n.indexOf(t)<0&&(o[t]=e[t]);if(e!=null&&typeof Object.getOwnPropertySymbols=="function")for(var r=0,t=Object.getOwnPropertySymbols(e);r<t.length;r++)n.indexOf(t[r])<0&&Object.prototype.propertyIsEnumerable.call(e,t[r])&&(o[t[r]]=e[t[r]]);return o};const m=()=>c(s(s({},u()),{ellipsis:{type:Boolean,default:void 0}}),["component"]),a=(e,n)=>{let{slots:o,attrs:t}=n;const r=s(s({},e),t),{ellipsis:f,rel:l}=r,i=g(r,["ellipsis","rel"]);p();const d=s(s({},i),{rel:l===void 0&&i.target==="_blank"?"noopener noreferrer":l,ellipsis:!!f,component:"a"});return delete d.navigate,b(y,d,o)};a.displayName="ATypographyLink";a.inheritAttrs=!1;a.props=m();const O=a;export{O as A};
//# sourceMappingURL=Link.bbb85664.js.map
