import{u as o,a as l}from"./index.d9a79603.js";import{d as w,r as u,b as n,ev as h,f as b,u as t,e as K,c,ex as d,L as x}from"./outputWidgets.be3472c2.js";import{P as A}from"./PlayerNavbar.f9ccf92b.js";import{K as B,_ as D,A as I,P as L}from"./TableView.vue_vue_type_script_setup_true_lang.1f9286c0.js";import{a as N}from"./asyncComputed.a619212b.js";import{g as S}from"./api.4007eec5.js";import{A as P}from"./index.13e9e3c1.js";import"./fetch.dd071db9.js";import"./pubsub.1063a0da.js";import"./PhKanban.vue.61eb6c5c.js";import"./PhSignOut.vue.ca4a6d5d.js";import"./Text.c9febe27.js";import"./index.4d45a574.js";import"./Link.bbb85664.js";import"./Paragraph.7601abde.js";import"./Title.65752aa0.js";import"./index.ec79aad2.js";import"./vuedraggable.umd.013cda09.js";import"./workspaces.7dc978fb.js";import"./runnerData.c8a20a02.js";import"./url.7fe1be7b.js";import"./record.820df198.js";import"./scripts.d40ca384.js";import"./envVars.3bfc7529.js";import"./api.3ae14449.js";import"./metadata.1f80fb9b.js";import"./PhCheckCircle.vue.7dbbe089.js";import"./PhScroll.vue.8db75bd1.js";import"./PhWebhooksLogo.vue.9a81ff31.js";import"./ant-design.468f41c3.js";import"./index.f70acf7e.js";import"./Modal.304207b8.js";import"./index.ba676107.js";import"./index.6773e8c7.js";import"./index.dea9b143.js";import"./index.4fd9f4c9.js";import"./CollapsePanel.7af79175.js";import"./index.557c5800.js";import"./index.a81a7d37.js";import"./isNumeric.75337b1e.js";import"./Card.1ee02828.js";import"./TabPane.3d3ce947.js";import"./hasIn.bddd0a1a.js";import"./LoadingOutlined.4087b648.js";import"./index.c71d8aa7.js";import"./Form.254a7379.js";import"./string.ad40d63c.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3b05e520-ab00-4c20-ba06-0c0e9ae7b415",e._sentryDebugIdIdentifier="sentry-dbid-3b05e520-ab00-4c20-ba06-0c0e9ae7b415")}catch{}})();const T={style:{padding:"20px"}},De=w({__name:"Threads",setup(e){const a=new L(o),s=new x(I,"kanban-selected-stages"),f=u(o.getUser()),g=["Kanban","Table view"],r=u("Kanban"),{result:y}=N(S),v=({path:i})=>{l.push({name:"form",params:{path:i.split("/")}})},k=()=>{o.removeUser(),l.push({name:"playerHome"})};return(i,m)=>{var p;return n(),h("div",null,[b(A,{"runner-data":t(y),"is-kanban-visible":!1,"user-email":(p=f.value)==null?void 0:p.claims.email,onLogout:k,onNavigate:v},null,8,["runner-data","user-email"]),K("div",T,[b(t(P),{value:r.value,"onUpdate:value":m[0]||(m[0]=_=>r.value=_),options:g,style:{"margin-bottom":"16px"}},null,8,["value"]),r.value==="Kanban"?(n(),c(B,{key:0,"kanban-repository":t(a),"kanban-stages-storage":t(s)},null,8,["kanban-repository","kanban-stages-storage"])):d("",!0),r.value==="Table view"?(n(),c(D,{key:1,"kanban-repository":t(a)},null,8,["kanban-repository"])):d("",!0)])])}}});export{De as default};
//# sourceMappingURL=Threads.eed19c72.js.map
