import{C as d}from"./ContentLayout.8a64aff0.js";import{A as l,K as y,_ as k,E as g}from"./TableView.vue_vue_type_script_setup_true_lang.1f9286c0.js";import{d as _,r as w,b as n,c as i,w as m,L as h,f as s,u as e,ex as c}from"./outputWidgets.be3472c2.js";import{l as v}from"./fetch.dd071db9.js";import{A as f,T}from"./TabPane.3d3ce947.js";import"./Card.1ee02828.js";import"./vuedraggable.umd.013cda09.js";import"./workspaces.7dc978fb.js";import"./runnerData.c8a20a02.js";import"./url.7fe1be7b.js";import"./record.820df198.js";import"./pubsub.1063a0da.js";import"./asyncComputed.a619212b.js";import"./scripts.d40ca384.js";import"./envVars.3bfc7529.js";import"./api.3ae14449.js";import"./metadata.1f80fb9b.js";import"./PhCheckCircle.vue.7dbbe089.js";import"./PhScroll.vue.8db75bd1.js";import"./PhWebhooksLogo.vue.9a81ff31.js";import"./ant-design.468f41c3.js";import"./index.f70acf7e.js";import"./Modal.304207b8.js";import"./Text.c9febe27.js";import"./index.ba676107.js";import"./index.6773e8c7.js";import"./index.dea9b143.js";import"./Paragraph.7601abde.js";import"./index.4d45a574.js";import"./Link.bbb85664.js";import"./Title.65752aa0.js";import"./index.4fd9f4c9.js";import"./CollapsePanel.7af79175.js";import"./index.557c5800.js";import"./index.a81a7d37.js";import"./isNumeric.75337b1e.js";import"./LoadingOutlined.4087b648.js";import"./index.c71d8aa7.js";import"./Form.254a7379.js";import"./hasIn.bddd0a1a.js";import"./string.ad40d63c.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[t]="a4a25ff7-a036-4ea0-a81e-c6c9c32180c2",a._sentryDebugIdIdentifier="sentry-dbid-a4a25ff7-a036-4ea0-a81e-c6c9c32180c2")}catch{}})();class K{constructor(t=v){this.fetch=t}async fork(t){return(await this.fetch("/_editor/api/stage_runs/fork",{method:"POST",body:JSON.stringify({stage_run_id:t}),headers:{"Content-Type":"application/json"}})).json()}}const bt=_({__name:"WorkflowThreads",setup(a){const t=new g,r=new K,u=new h(l,"kanban-selected-stages"),o=w("kanban");return(S,p)=>(n(),i(d,{"full-width":""},{default:m(()=>[s(e(T),{activeKey:o.value,"onUpdate:activeKey":p[0]||(p[0]=b=>o.value=b)},{default:m(()=>[s(e(f),{key:"kanban",tab:"Kanban View"}),s(e(f),{key:"table",tab:"Table View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(n(),i(y,{key:0,"kanban-repository":e(t),"kanban-stages-storage":e(u),"stage-run-repository":e(r)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):c("",!0),o.value==="table"?(n(),i(k,{key:1,"kanban-repository":e(t)},null,8,["kanban-repository"])):c("",!0)]),_:1}))}});export{bt as default};
//# sourceMappingURL=WorkflowThreads.e1bfce41.js.map
