import{d as b,eJ as g,r as y,J as v,b as h,ev as k,f as m,u as a,v as w}from"./outputWidgets.be3472c2.js";import{g as H}from"./api.4007eec5.js";import{a as p}from"./asyncComputed.a619212b.js";import{P as I}from"./PlayerNavbar.f9ccf92b.js";import{H as D}from"./HomeContent.f12da4f6.js";import{u as s}from"./index.d9a79603.js";import"./runnerData.c8a20a02.js";import"./url.7fe1be7b.js";import"./PhKanban.vue.61eb6c5c.js";import"./PhSignOut.vue.ca4a6d5d.js";import"./Text.c9febe27.js";import"./index.4d45a574.js";import"./Link.bbb85664.js";import"./Paragraph.7601abde.js";import"./Title.65752aa0.js";import"./index.ec79aad2.js";import"./PhArrowSquareOut.vue.03d709e6.js";import"./index.040ecb89.js";import"./Card.1ee02828.js";import"./TabPane.3d3ce947.js";import"./hasIn.bddd0a1a.js";import"./index.ba676107.js";import"./fetch.dd071db9.js";import"./pubsub.1063a0da.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="8d24cbb0-0919-4489-9caa-ed7e8fb71088",o._sentryDebugIdIdentifier="sentry-dbid-8d24cbb0-0919-4489-9caa-ed7e8fb71088")}catch{}})();const x={class:"page"},C=b({__name:"Home",setup(o){const e=g(),r=y(s.getUser()),{result:c,refetch:u}=p(async()=>(await s.allow("kanban")).status==="ALLOWED");v(r,()=>u());const l=({path:t})=>{e.push({name:"form",params:{path:t.split("/")}})},{result:n,loading:d}=p(H),f=t=>{e.push({path:`/${t}`})},_=()=>{s.removeUser(),e.push({name:"playerHome"})};return(t,L)=>{var i;return h(),k("div",x,[m(I,{"runner-data":a(n),"is-kanban-visible":a(c)||!1,"user-email":(i=r.value)==null?void 0:i.claims.email,onNavigate:l,onLogout:_},null,8,["runner-data","is-kanban-visible","user-email"]),m(D,{workspace:a(n),loading:a(d),onFormClick:f},null,8,["workspace","loading"])])}}});const Z=w(C,[["__scopeId","data-v-f12c98c4"]]);export{Z as default};
//# sourceMappingURL=Home.1631d94f.js.map
