import{P as b}from"./PlayerNavbar.f9ccf92b.js";import{g as h}from"./api.4007eec5.js";import{a as d}from"./asyncComputed.a619212b.js";import{W as v}from"./WidgetsFrame.93ee4bfa.js";import{d as w,r as k,J as D,eJ as I,eD as x,b as p,ev as C,e as o,f as E,u as t,c as N,w as P,ex as V,eG as f,v as B}from"./outputWidgets.be3472c2.js";import{u as n}from"./index.d9a79603.js";import"./PhKanban.vue.61eb6c5c.js";import"./PhSignOut.vue.ca4a6d5d.js";import"./Text.c9febe27.js";import"./index.4d45a574.js";import"./Link.bbb85664.js";import"./Paragraph.7601abde.js";import"./Title.65752aa0.js";import"./index.ec79aad2.js";import"./runnerData.c8a20a02.js";import"./url.7fe1be7b.js";import"./fetch.dd071db9.js";import"./pubsub.1063a0da.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new q().stack;a&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[a]="b30e4892-29d3-4797-9981-1cbee66b4e77",r._sentryDebugIdIdentifier="sentry-dbid-b30e4892-29d3-4797-9981-1cbee66b4e77")}catch{}})();const L={class:"error"},W={class:"inner-content"},A=w({__name:"Error",setup(r){const a=k(n.getUser()),{result:i,refetch:_}=d(async()=>(await n.allow("kanban")).status==="ALLOWED");D(a,()=>_());const u=I(),g=({path:e})=>{u.push({name:"form",query:c.query,params:{path:e.split("/")}})},c=x(),{result:s}=d(h),y=()=>{n.removeUser(),u.push({name:"playerHome"})},m=()=>{const{status:e}=c.params;switch(e){case"404":return{status:e,message:"Page not found."};case"403":return{status:e,message:"Access denied. Please contact your administrator."};default:return{status:"500",message:"An unknown error ocurred. Please try again or contact support."}}};return(e,F)=>{var l;return p(),C("div",null,[o("div",L,[E(b,{"user-email":(l=a.value)==null?void 0:l.claims.email,"is-kanban-visible":t(i)||!1,"runner-data":t(s),onNavigate:g,onLogout:y},null,8,["user-email","is-kanban-visible","runner-data"]),t(s)?(p(),N(v,{key:0,"main-color":t(s).mainColor,theme:t(s).theme,"font-family":t(s).fontFamily,style:{height:"100vh",width:"100%"}},{default:P(()=>[o("div",W,[o("h1",null,f(m().status),1),o("p",null,f(m().message),1)])]),_:1},8,["main-color","theme","font-family"])):V("",!0)])])}}});const q=B(A,[["__scopeId","data-v-98d8191f"]]);export{q as default};
//# sourceMappingURL=Error.c57a485e.js.map
