import{_ as I}from"./logo.084e5d7c.js";import{v,b as r,ev as p,eB as C,eC as w,e as d,d as x,eJ as N,a as D,u as e,c as l,bg as L,w as t,f as s,ar as c,eG as m,bF as f,cB as S,cx as $,eN as V,eE as z,f9 as E,aD as y,ex as F,di as R}from"./outputWidgets.be3472c2.js";import{b as h,c as T}from"./router.87bf43b6.js";import{a as P}from"./asyncComputed.a619212b.js";import{F as j}from"./PhSignOut.vue.ca4a6d5d.js";import{A as q}from"./Text.c9febe27.js";import{A as G}from"./index.ec79aad2.js";import{B as H,A as J,b as M}from"./index.7cde6902.js";import{B as O}from"./BookOutlined.53049b66.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[a]="93c8b37b-b735-4a8d-9552-0655fd11729a",o._sentryDebugIdIdentifier="sentry-dbid-93c8b37b-b735-4a8d-9552-0655fd11729a")}catch{}})();const U={},k=o=>(C("data-v-46e041c1"),o=o(),w(),o),K={class:"logo"},Q=k(()=>d("img",{class:"logo-img",src:I,alt:"Abstra cloud logo"},null,-1)),W=k(()=>d("span",null,"Abstra",-1)),X=[Q,W];function Y(o,a){return r(),p("div",K,X)}const Z=v(U,[["render",Y],["__scopeId","data-v-46e041c1"]]),ee={style:{display:"flex","flex-direction":"column",gap:"10px"}},te={style:{display:"flex",gap:"5px"}},oe=x({__name:"LoginBlock",setup(o){function a(b){const g=b.split("@")[0];return V.exports.kebabCase(g).toUpperCase().split("-").slice(0,2).map(u=>u[0]).join("")}const i=N(),{result:n,loading:_,refetch:A}=P(async()=>h.getAuthor());function B(){h.removeAuthor(),T.shutdown(),A(),i.push({name:"login"})}return(b,g)=>{const u=D("router-link");return e(_)?(r(),l(e(L),{key:0})):e(n)?(r(),l(e($),{key:1,placement:"bottomRight"},{content:t(()=>[d("div",ee,[s(e(q),{size:"small",type:"secondary"},{default:t(()=>[c(m(e(n).claims.email),1)]),_:1}),s(e(f),{type:"text",onClick:B},{default:t(()=>[d("div",te,[s(e(j),{size:"20"}),c(" Logout ")])]),_:1})])]),default:t(()=>[s(e(S),{align:"center",style:{cursor:"pointer"}},{default:t(()=>[s(e(G),{shape:"square"},{default:t(()=>[c(m(a(e(n).claims.email)),1)]),_:1})]),_:1})]),_:1})):(r(),l(e(f),{key:2},{default:t(()=>[s(u,{to:"/login"},{default:t(()=>[c("Login")]),_:1})]),_:1}))}}}),se={class:"extra"},ae=x({__name:"Navbar",props:{breadcrumb:{}},setup(o){return(a,i)=>(r(),l(e(M),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{subTitle:t(()=>[a.breadcrumb?(r(),l(e(H),{key:0,style:{margin:"0px 50px"}},{default:t(()=>[(r(!0),p(y,null,z(a.breadcrumb,(n,_)=>(r(),l(e(J),{key:_},{default:t(()=>[s(e(E),{to:n.path},{default:t(()=>[c(m(n.label),1)]),_:2},1032,["to"])]),_:2},1024))),128))]),_:1})):F("",!0)]),title:t(()=>[s(Z)]),extra:t(()=>[d("div",se,[s(e(f),{class:"docs-button",href:"https://docs.abstra.io/",target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:t(()=>[s(e(O))]),default:t(()=>[a.$slots.default?R(a.$slots,"default",{key:0},void 0,!0):(r(),p(y,{key:1},[c("Docs")],64))]),_:3}),s(oe)])]),_:3}))}});const me=v(ae,[["__scopeId","data-v-31e2a422"]]);export{me as N};
//# sourceMappingURL=Navbar.27bba2c6.js.map
