import{u as n}from"./index.d9a79603.js";import"./outputWidgets.be3472c2.js";import{r as s,w as a}from"./runnerData.c8a20a02.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8ef0f0cb-ad23-4022-8f48-a3be195dffe1",e._sentryDebugIdIdentifier="sentry-dbid-8ef0f0cb-ad23-4022-8f48-a3be195dffe1")}catch{}})();async function i(e){const t=await fetch(`/_pages/${e}`,{headers:n.authHeaders()});if(t.status==404)return null;if(!t.ok)throw new Error(await t.text());const{form:r}=await t.json();return r?s(r):null}async function d(){const e=await fetch("/_workspace");if(e.status!=200)return a({});const t=await e.json();return a(t)}export{i as f,d as g};
//# sourceMappingURL=api.4007eec5.js.map
