import{d as a,b as o,ev as s,f as d,u as r,bg as _,v as c}from"./outputWidgets.be3472c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="b335ea02-3772-4009-a064-bb9bc7f0694b",e._sentryDebugIdIdentifier="sentry-dbid-b335ea02-3772-4009-a064-bb9bc7f0694b")}catch{}})();const i={class:"centered"},b=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(r(_))]))}});const p=c(b,[["__scopeId","data-v-1da18eee"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.83bf440d.js.map
