import{F as t}from"./Form.254a7379.js";import{b2 as d,ck as n}from"./outputWidgets.be3472c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="55c73d30-fd9a-4bca-a124-63f74c7ddab0",e._sentryDebugIdIdentifier="sentry-dbid-55c73d30-fd9a-4bca-a124-63f74c7ddab0")}catch{}})();t.useInjectFormItemContext=d;t.ItemRest=n;t.install=function(e){return e.component(t.name,t),e.component(t.Item.name,t.Item),e.component(n.name,n),e};
//# sourceMappingURL=index.c71d8aa7.js.map
