import{cv as o}from"./outputWidgets.be3472c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="21b89e93-56ce-4311-883a-68a3b2f5cf87",e._sentryDebugIdIdentifier="sentry-dbid-21b89e93-56ce-4311-883a-68a3b2f5cf87")}catch{}})();const f=(e,r,n)=>{o.error({message:e,description:r,onClick:n})};export{f as p};
//# sourceMappingURL=popupNotifcation.9025cc7b.js.map
