.data-container[data-v-541d30a8]{height:100px}.description[data-v-a8ca44f6]{margin-bottom:20px;font-style:italic;display:block}.form-settings[data-v-596854dc]{height:100%;overflow:auto;box-sizing:border-box;padding:0 0 20px}.form-preview-container[data-v-0bb5e782]{flex-grow:1;border-radius:10px;overflow:hidden}
