.error[data-v-98d8191f]{display:flex;justify-content:center;align-items:center;flex-direction:column;height:100vh}.inner-content[data-v-98d8191f]{display:flex;justify-content:center;align-items:center;flex-direction:column;flex-grow:1}
