import{B as d}from"./BookOutlined.53049b66.js";import{d as c,b as o,c as l,w as a,f,u as n,di as i,ev as u,ar as b,aD as p,bF as y}from"./outputWidgets.be3472c2.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="c0d7fb53-9b4b-4ec8-8041-1204c2d684e2",t._sentryDebugIdIdentifier="sentry-dbid-c0d7fb53-9b4b-4ec8-8041-1204c2d684e2")}catch{}})();const k=c({__name:"DocsButton",props:{path:{}},setup(t){return(e,r)=>{var s;return o(),l(n(y),{class:"docs-button",href:`https://docs.abstra.io/${(s=e.path)!=null?s:""}`,target:"_blank",type:"link",style:{color:"#d14056"},size:"small"},{icon:a(()=>[f(n(d))]),default:a(()=>[e.$slots.default?i(e.$slots,"default",{key:0}):(o(),u(p,{key:1},[b("Docs")],64))]),_:3},8,["href"])}}});export{k as _};
//# sourceMappingURL=DocsButton.vue_vue_type_script_setup_true_lang.f9aebc41.js.map
