import{a as e,A as a,B as i}from"./Text.c9febe27.js";import{A as o}from"./Link.bbb85664.js";import{A as r}from"./Paragraph.7601abde.js";import{A as d}from"./Title.65752aa0.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[t]="3d9602ec-463e-4f69-ab8d-c2c2d88e8b62",n._sentryDebugIdIdentifier="sentry-dbid-3d9602ec-463e-4f69-ab8d-c2c2d88e8b62")}catch{}})();e.Text=a;e.Title=d;e.Paragraph=r;e.Link=o;e.Base=i;e.install=function(n){return n.component(e.name,e),n.component(e.Text.displayName,a),n.component(e.Title.displayName,d),n.component(e.Paragraph.displayName,r),n.component(e.Link.displayName,o),n};
//# sourceMappingURL=index.4d45a574.js.map
