import{f as o,eH as u,eV as f}from"./outputWidgets.be3472c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="a78363d4-69b1-439a-af8a-361083db6277",e._sentryDebugIdIdentifier="sentry-dbid-a78363d4-69b1-439a-af8a-361083db6277")}catch{}})();function d(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){l(e,a,n[a])})}return e}function l(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var i=function(t,n){var r=d({},t,n.attrs);return o(u,d({},r,{icon:f}),null)};i.displayName="LoadingOutlined";i.inheritAttrs=!1;const s=i;export{s as L};
//# sourceMappingURL=LoadingOutlined.4087b648.js.map
