import{V as s,f as d,R as p}from"./outputWidgets.be3472c2.js";import{B as b,b as c}from"./Text.c9febe27.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="3c4fc33b-8d84-4a00-bdda-70b11a7398bc",a._sentryDebugIdIdentifier="sentry-dbid-3c4fc33b-8d84-4a00-bdda-70b11a7398bc")}catch{}})();const f=()=>p(c(),["component"]),e=(a,r)=>{let{slots:t,attrs:o}=r;const n=s(s(s({},a),{component:"div"}),o);return d(b,n,t)};e.displayName="ATypographyParagraph";e.inheritAttrs=!1;e.props=f();const g=e;export{g as A};
//# sourceMappingURL=Paragraph.7601abde.js.map
