import{d as b,eD as f,eJ as C,I as g,b as _,c as I,u as h,eR as w}from"./outputWidgets.be3472c2.js";import{b as k}from"./index.86288308.js";import"./router.87bf43b6.js";import{C as i}from"./connector.8db750b4.js";import{a as x}from"./asyncComputed.a619212b.js";import{G as D}from"./PhPencil.vue.6be3e07b.js";import{C as E}from"./CrudView.08af3b90.js";import"./record.820df198.js";import"./pubsub.1063a0da.js";import"./Form.254a7379.js";import"./hasIn.bddd0a1a.js";import"./popupNotifcation.9025cc7b.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.f9aebc41.js";import"./BookOutlined.53049b66.js";import"./url.7fe1be7b.js";import"./Paragraph.7601abde.js";import"./Text.c9febe27.js";import"./Modal.304207b8.js";import"./index.ba676107.js";import"./Title.65752aa0.js";import"./index.6773e8c7.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="98fbad4c-beba-4b47-948a-9759287d0623",o._sentryDebugIdIdentifier="sentry-dbid-98fbad4c-beba-4b47-948a-9759287d0623")}catch{}})();const Q=b({__name:"Connectors",setup(o){const r=f(),a=C(),c=r.params.projectId;async function s(e){const t=await i.create(c,e.name,e.type);a.push({name:"connectorEditor",params:{connectorId:t.id}})}const p=[{key:"name",label:"Connector name",type:"text"},{key:"type",label:"Connector type",type:Object.entries(k.schema).map(([e,t])=>({value:e,label:t.label}))}],{loading:m,result:l,refetch:d}=x(()=>i.list(c)),u=g(()=>{var e,t;return{columns:[{name:"Name"},{name:"Type"},{name:"",align:"right"}],rows:(t=(e=l.value)==null?void 0:e.map(n=>({key:n.id,cells:[{type:"link",text:n.name,to:{name:"connectorEditor",params:{connectorId:n.id}}},{type:"text",text:n.type},{type:"actions",actions:[{icon:D,label:"Edit",onClick({key:y}){a.push({name:"connectorEditor",params:{connectorId:y}})}},{icon:w,label:"Delete",dangerous:!0,async onClick(){await n.delete(),d()}}]}]})))!=null?t:[]}});return(e,t)=>(_(),I(E,{"entity-name":"connector",loading:h(m),title:"Connectors",description:"Each connector is a version of your app. You can create a new connector by deploying your app from the local editor.","empty-title":"No connectors here yet",table:u.value,fields:p,"create-button-text":"Create connector",onCreate:s},null,8,["loading","table"]))}});export{Q as default};
//# sourceMappingURL=Connectors.5fa56d23.js.map
