import{F as b}from"./PhArrowSquareOut.vue.03d709e6.js";import{d as k,I as w,b as o,ev as u,c,u as t,w as n,ew as v,bg as h,ar as m,aD as C,eE as x,f as d,eG as I,v as D}from"./outputWidgets.be3472c2.js";import"./index.4d45a574.js";import"./index.040ecb89.js";import{A as y}from"./index.ba676107.js";import{a as _}from"./Text.c9febe27.js";import{C as B}from"./Card.1ee02828.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[r]="2ced0190-3e95-499b-acd6-d4ef5bfc73f2",a._sentryDebugIdIdentifier="sentry-dbid-2ced0190-3e95-499b-acd6-d4ef5bfc73f2")}catch{}})();const F=k({__name:"HomeContent",props:{loading:{type:Boolean},workspace:{}},emits:["form-click"],setup(a,{emit:r}){const p=a,f=w(()=>{var e,i;return(i=(e=p.workspace)==null?void 0:e.sidebar.filter(s=>s.visible))!=null?i:[]});function g(e){r("form-click",e)}return(e,i)=>{var s;return o(),u("div",{class:"container",style:v({backgroundColor:(s=e.workspace)==null?void 0:s.theme})},[e.loading?(o(),c(t(h),{key:0})):f.value.length===0?(o(),c(t(_),{key:1,type:"secondary",style:{"font-size":"18px"}},{default:n(()=>[m(" There are no public forms available ")]),_:1})):(o(),c(t(y),{key:2,vertical:"",gap:"large",style:{padding:"120px 0"}},{default:n(()=>[(o(!0),u(C,null,x(f.value,l=>(o(),c(t(B),{key:l.id,class:"form-card",onClick:H=>g(l.path)},{default:n(()=>[d(t(y),{gap:"large",align:"center",justify:"space-between"},{default:n(()=>[d(t(_),{style:{"font-size":"18px","font-weight":"500"}},{default:n(()=>[m(I(l.name),1)]),_:2},1024),d(t(b),{color:"#000",width:"20"})]),_:2},1024)]),_:2},1032,["onClick"]))),128))]),_:1}))],4)}}});const j=D(F,[["__scopeId","data-v-e246816b"]]);export{j as H};
//# sourceMappingURL=HomeContent.f12da4f6.js.map
