import{eZ as t,e_ as r}from"./outputWidgets.be3472c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="9671db34-5b07-469f-aa42-f4cc15584d01",e._sentryDebugIdIdentifier="sentry-dbid-9671db34-5b07-469f-aa42-f4cc15584d01")}catch{}})();function a(e,n){return t(1,arguments),r(e,Date.now(),n)}export{a as f};
//# sourceMappingURL=index.dea9b143.js.map
