import{d as o,b as s,ev as a,e as d,di as r,ez as l,v as _}from"./outputWidgets.be3472c2.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="676431b1-fb05-4237-a289-0229450b6db9",e._sentryDebugIdIdentifier="sentry-dbid-676431b1-fb05-4237-a289-0229450b6db9")}catch{}})();const u={class:"content-layout"},f=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,n)=>(s(),a("div",u,[d("div",{class:l(["centered-layout",{"full-width":t.fullWidth}])},[r(t.$slots,"default",{},void 0,!0)],2)]))}});const c=_(f,[["__scopeId","data-v-00ef87a4"]]);export{c as C};
//# sourceMappingURL=ContentLayout.8a64aff0.js.map
