.logo[data-v-46e041c1]{display:flex;align-items:center}.logo .logo-img[data-v-46e041c1]{height:40px}.logo span[data-v-46e041c1]{font-size:20px;font-weight:600;margin-left:10px}.extra[data-v-31e2a422]{display:flex;align-items:center;height:40px;justify-content:center;gap:20px}
